==> nextcloud-app-calendar-1%3A1.7.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/vi.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Lịch",
    "%s has published the calendar »%s«" : "%s vừa đăng tải thông tin vào lịch »%s«",
    "Hello," : "Xin chào,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Chúng tôi muốn thông báo với bạn rằng %s vừa đăng tải thông tin vào lịch calendar »%s«.",
    "Open »%s«" : "Mở »%s«",
    "Cheers!" : "Xin chúc mừng!",
    "Recipient" : "Người nhận",
    "Too many redirects. Aborting ..." : "Có quá nhiều điều hướng ngược. Đang loại bỏ ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Máy chủ từ xa không cho chúng tôi truy cập vào lịch  (Lỗi HTTP {%s} )",
    "Error connecting to remote server" : "Lỗi khi kết nối từ máy chủ từ xa.",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Lỗi khi yêu cầu cung cấp tài nguyên trên máy chủ từ xa. Điều này có thể liên quan đến không hợp lệ về chứng thư số.",
    "Error requesting resource on remote server" : "Lỗi khi yêu cầu tài nguyên trên máy chủ từ xa",
    "Individual" : "Cá nhân",
    "Group" : "N",
    "Resource" : "Tài nguyên",
    "Room" : "Phòng",
    "Unknown" : " Chưa biết",
    "Required" : "Bắt buộc",
    "Optional" : "Tùy chọn",
    "Does not attend" : "Không tham dự",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Không rõ bạn đang ở múi giờ nào ({tz}), chuyển lại múi giờ UTC",
    "Please create a calendar first." : "Xin vui lòng tạo một lịch làm việc trước.",
    "New event" : "Sự kiện mới",
    "CalDAV address for clients" : "Địa chỉ CalDAV cho người dùng đầu cuối",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Một số sự kiện trong lịch này bị hỏng. Vui lòng kiểm tra giao diện điều khiển JS để biết thêm thông tin.",
    "Share Calendar" : "Chia sẻ lịch",
    "Shared" : "Được chia sẻ",
    "Could not save WebCal-calendar" : "Không thể lưu WebCal-calendar",
    "WebDAV address for subscriptions" : "Địa chỉ WebDAV cho các đăng ký",
    "Email sent." : "Đã gửi email.",
    "Could not send your email." : "Không thể gửi email của bạn.",
    "group" : "nhóm",
    "Details" : "Chi tiết",
    "Attendees" : "Người tham gia",
    "Reminders" : "Nhắc nhở",
    "Repeating" : "Lặp",
    "When shared show full event" : "Khi được chia sẻ thì thể hiện đầy đủ sự kiện",
    "When shared show only busy" : "Khi được chia sẻ thì chỉ thể hiện đang bận",
    "When shared hide this event" : "Khi được chia sẻ thì ẩn sự kiện này đi",
    "Confirmed" : "Đã xác nhận",
    "Tentative" : "Chưa chắc chắn",
    "Cancelled" : "Bị hủy",
    "Please add a title." : "Xin vui lòng thêm một tiêu đề",
    "Please select a calendar." : "Xin vui lòng chọn lịch.",
    "The event can not end before it starts." : "Sự kiện này không thể kết thúc trước khi nó bắt đầu.",
    "Global" : "Chung",
    "None" : "Không gì cả",
    "Every day" : "Hàng ngày",
    "Every week" : "Hàng tuần",
    "Every month" : "Hàng tháng",
    "Every year" : "Hàng năm",
    "never" : "không thay đổi",
    "after" : "sau khi",
    "Automatic ({timezone})" : "Tự động ({timezone})",
    "How about getting started by importing some calendars?" : "Làm thế nào về việc bắt đầu bằng cách nhập một số lịch?",
    "At time of event" : "Tại thời điểm sự kiện",
    "5 minutes before" : "Trước 5 phút",
    "10 minutes before" : "Trước 10 phút",
    "15 minutes before" : "Trước 15 phút",
    "30 minutes before" : "Trước 30 phút",
    "1 hour before" : "Trước 1 tiếng",
    "2 hours before" : "Trước 2 tiếng",
    "Custom" : "Tùy chỉnh",
    "Audio" : "Âm thanh",
    "Email" : "Thư điện tử",
    "Pop-up" : "Pop-up",
    "sec" : "giây",
    "min" : "phút",
    "hours" : "giờ",
    "days" : "ngày",
    "week" : "tuần",
    "before" : "trước",
    "start" : "thời gian bắt đầu",
    "end" : "thời gian kết thúc",
    "Editing reminders of unknown type not supported." : "Không hỗ trợ chỉnh sửa lời nhắc thuộc loại không xác định.",
    "Week {number} of {year}" : "Tuần thứ {number} của năm {year}",
    "Successfully imported {imported} objects" : "Đã nhập thành công đối tượng {imported}",
    "Imported {imported} out of {all}, skipped one duplicate" : "Đã nhập {imported} trong số {all}, bỏ qua một bản sao",
    "Imported {imported} out of {all}, one failure" : "Đã nhập {imported} trong số {all}, một lỗi",
    "Imported {imported} out of {all}, {errors} failures" : "Đã nhập {imported} trong số {all}, {errors} lỗi",
    "Imported {imported} out of {all}, skipped {duplicates} duplicates" : "Đã nhập {imported} trong số {all}, bỏ qua các bản sao {duplicates} bị trùng lặp",
    "Imported {imported} out of {all}, {errors} failures, skipped {duplicates} duplicates" : "Đã nhập {imported} trong số {all}, {errors} lỗi, bỏ qua các bản sao {duplicates} bị trùng lặp",
    "Audio alarm {time} before the event starts" : "Âm thanh nhắc nhở {time} trước khi sự kiện bắt đầu",
    "Pop-up {time} before the event starts" : "Cửa sổ thông báo {time} trước khi sự kiện bắt đầu",
    "Email {time} before the event starts" : "Gửi email {time} trước khi sự kiện bắt đầu",
    "None {time} before the event starts" : "Không làm gì {time} trước khi sự kiện bắt đầu",
    "{type} {time} before the event starts" : "{type} {time} trước khi sự kiện bắt đầu",
    "Audio alarm {time} before the event ends" : "Âm thanh nhắc nhở {time} trước khi sự kiện kết thúc",
    "Pop-up {time} before the event ends" : "Cửa sổ thông báo {time} trước khi sự kiện kết thúc",
    "Email {time} before the event ends" : "Gửi email {time} trước khi sự kiện kết thúc",
    "None {time} before the event ends" : "Không làm gì {time} trước khi sự kiện kết thúc",
    "{type} {time} before the event ends" : "{type} {time} trước khi sự kiện kết thúc",
    "Audio alarm {time} after the event starts" : "Âm thanh nhắc nhở {time} sau khi sự kiện bắt đầu",
    "Pop-up {time} after the event starts" : "Cửa sổ thông báo {time} sau khi sự kiện bắt đầu",
    "Email {time} after the event starts" : "Gửi thông báo {time} sau khi sự kiện bắt đầu",
    "None {time} after the event starts" : "Không làm gì {time} sau khi sự kiện bắt đầu",
    "{type} {time} after the event starts" : "{type} {time} sau khi sự kiện bắt đầu",
    "Audio alarm {time} after the event ends" : "Âm thanh nhắc nhở {time} sau khi sự kiện kết thúc",
    "Pop-up {time} after the event ends" : "Cửa sổ thông báo {time} sau khi sự kiện kết thúc",
    "Email {time} after the event ends" : "Gửi email  {time} sau khi sự kiện kết thúc",
    "None {time} after the event ends" : "Không làm gì {time} sau khi sự kiện kết thúc",
    "{type} {time} after the event ends" : "{type}  {time} sau khi sự kiện kết thúc",
    "Audio alarm at the event's start" : "Âm thanh nhắc nhở khi bắt đầu sự kiện",
    "Pop-up at the event's start" : "Cửa sổ thông báo khi bắt đầu sự kiện",
    "Email at the event's start" : "Gửi email khi bắt đầu sự kiện",
    "None at the event's start" : "Không làm gì khi bắt đầu sự kiện",
    "{type} at the event's start" : "{type} khi bắt đầu sự kiện",
    "Audio alarm at the event's end" : "Âm thanh nhắc nhở khi sự kiện kết thúc",
    "Pop-up at the event's end" : "Cửa sổ thông báo khi sự kiện kết thúc",
    "Email at the event's end" : "Gửi email khi sự kiện kết thúc",
    "None at the event's end" : "Không làm gì khi sự kiện kết thúc",
    "{type} at the event's end" : " {type} khi sự kiện kết thúc",
    "Audio alarm at {time}" : "Âm thanh nhắc nhở lúc {time}",
    "Pop-up at {time}" : "Cửa sổ thông báo lúc {time}",
    "Email at {time}" : "Gửi email lúc {time}",
    "None at {time}" : "Không làm gì lúc {time}",
    "{type} at {time}" : "{type} lúc {time}",
    "{calendar} shared by {owner}" : "{calendar} được chia sẽ bởi {owner}",
    "Please enter a valid WebCal-URL" : "Hãy nhập một URL hợp lệ WebCal-URL",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Lỗi nghiêm trọng trong proxy webcal. Vui lòng liên hệ với quản trị viên để biết thêm thông tin.",
    "A Calendar app for Nextcloud" : "Một ứng dụng Lịch nhắc nhở cho Hệ thống",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events.\n* 🙈 **We’re not reinventing the wheel!** Based on the great [davclient.js](https://github.com/evert/davclient.js), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Ứng dụng Lịch có giao diện người dùng được tích hợp cho máy chủ CalDAV của Hệ thống. Dễ dàng đồng bộ hóa các sự kiện từ các thiết bị khác nhau với Hệ thống của bạn và chỉnh sửa chúng trực tuyến.\n\n* 🚀 **Tích hợp với các ứng dụng khác của Hệ thống!** Hiện tại có ứng dụng Danh bạ - tương lai sẽ nhiều hơn.\n* 🌐 **Hỗ trợ WebCal** Bạn muốn xem các trận đấu của đội yêu thích trong lịch của mình? Không vấn đề gì!\n* 🙋 **Thành phần tham dự!** Mời mọi người tham gia sự kiện của bạn.\n* 🙈 **Chúng tôi không phát minh lại công cụ!** Ứng dụng dựa trên [davclient.js](https://github.com/evert/davclient.js), [ical.js](https://github.com/mozilla-comm/ical.js) và thư viện [fullcalendar](https://github.com/fullcalendar/fullcalendar).",
    "Title of the Event" : "Tên sự kiện",
    "Starts" : "Bắt đầu",
    "Ends" : "Kết thúc",
    "All day Event" : "Sự kiện cả ngày",
    "Delete" : "Xóa",
    "Cancel" : "Hủy",
    "More ..." : "Nhiều hơn...",
    "Create" : "Tạo",
    "Update" : "Cập nhật",
    "Close" : "Đóng",
    "Location" : "Vị trí",
    "Description" : "Mô tả",
    "Event status" : "Trạng thái sự kiện",
    "Visibility when sharing" : "Hiển thị khi chia sẻ",
    "Export" : "Xuất ra",
    "%s has published the calendar %s" : "%s đã công khai lịch làm việc  %s",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Chúng tôi muốn thông báo cho bạn rằng %s đã lên lịch {boldstart} %s {boldend}.",
    "Click here to access it" : "Nhấp vào đây để truy cập",
    "We wanted to inform you that %s has published the calendar %s." : "Chúng tôi muốn thông báo cho bạn rằng %s đã lên lịch %s.",
    "Click on the link below to access it" : "Nhấp vào liên kết bên dưới để truy cập",
    "Day" : "Ngày",
    "Week" : "Tuần",
    "Month" : "Tháng",
    "Today" : "Hôm nay",
    "More" : "hơn",
    "Edit" : "Sửa",
    "Link" : "Liên kết",
    "iCal link" : "iCal liên kết",
    "Download" : "Tải về",
    "can edit" : "có thể chỉnh sửa",
    "Share link" : "Liên kết chia sẽ",
    "Public access" : "Truy cập công khai",
    "Email link to person" : "Gửi liên kết đến cá nhân",
    "Send" : "Gửi",
    "New Calendar" : "Lịch mới",
    "Name" : "Tên",
    "New Subscription" : "Đăng ký mới",
    "Go back" : "Quay lại",
    "Go forward" : "Tiếp tục",
    "Calendar does not exist" : "Lịch không tồn tại",
    "Maybe you got a wrong link or the calendar was unshared?" : "Có thể bạn đã nhận được liên kết sai hoặc lịch không được chia sẻ?",
    "Edit event" : "Sửa sự kiện",
    "Delete Event" : "Xóa sự kiện",
    "Save Event" : "Lưu sự kiện",
    "Time" : "Thời gian",
    "Type" : "Loại",
    "Relative" : "Liên quan",
    "Absolute" : "Chính xác",
    "Repeat" : "Lặp lại",
    "times every" : "mỗi lần",
    "Email reminders have not been implemented in the CalDAV server yet, so none will be sent." : "Lời nhắc qua email chưa được triển khai trong máy chủ CalDAV, vì vậy sẽ không có thư nào được gửi.",
    "Add" : "Thêm",
    "Email address of attendee" : "Địa chỉ email của người tham dự",
    "Please add your email address in the personal settings in order to add attendees." : "Vui lòng thêm địa chỉ email của bạn trong cài đặt cá nhân để thêm người tham dự.",
    "from" : "từ",
    "to" : "đến",
    "This event's repeating rule is not supported yet." : "Quy tắc lặp lại của sự kiện này chưa được hỗ trợ.",
    "Support for advanced rules will be added with subsequent updates." : "Hỗ trợ cho các quy tắc nâng cao sẽ được thêm vào với các bản cập nhật tiếp theo.",
    "Reset repeating rule" : "Đặt lại quy tắc lặp",
    "Repeat every ..." : "Lặp lại mỗi...",
    "end repeat ..." : "kết thúc lặp lại...",
    "times" : "thời gian",
    "Import Calendars" : "Nhập lịch vào",
    "Import canceled" : "Đã hủy nhập",
    "Analyzing calendar" : "Phân tích lịch",
    "The file contains objects incompatible with the selected calendar" : "Tệp chứa các đối tượng không tương thích với lịch đã chọn",
    "New calendar" : "Lịch mới",
    "File is empty" : "Tập tin rỗng",
    "File could not be parsed" : "Không thể phân tích cú pháp tệp",
    "Import scheduled" : "Nhập lịch biểu",
    "%s shared the calendar <strong>%s</strong> with you" : "%s đã chia sẽ lịch biểu <strong>%s</strong> với bạn",
    "Embed" : "Nhúng",
    "Iframe to integrate" : "Khung nội tuyến để tích hợp",
    "Publish URL" : "URL công khai",
    "Settings & import" : "Thiết lập & Nhập vào",
    "Import calendar" : "Nhập lịch biểu",
    "No Calendars selected for import" : "Không có lịch biểu nào được chọn để nhập vào",
    "Skip simple event editor" : "Bỏ qua trình soạn thảo sự kiện đơn giản",
    "Show week numbers" : "Hiển thị số tuần",
    "Timezone" : "Múi giờ",
    "Primary CalDAV address" : "Địa chỉ CalDAV chính",
    "iOS/macOS CalDAV address" : "Địa chỉ CalDAV iOS/macOS",
    "Subscribe" : "Theo dõi"
},
"nplurals=1; plural=0;");

==> nextcloud-app-calendar-1%3A2.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/vi.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Lịch",
    "%s has published the calendar »%s«" : "%s vừa đăng tải thông tin vào lịch »%s«",
    "Hello," : "Xin chào,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Chúng tôi muốn thông báo với bạn rằng %s vừa đăng tải thông tin vào lịch calendar »%s«.",
    "Open »%s«" : "Mở »%s«",
    "Cheers!" : "Xin chúc mừng!",
    "A Calendar app for Nextcloud" : "Một ứng dụng Lịch nhắc nhở cho Hệ thống",
    "Today" : "Hôm nay",
    "Day" : "Ngày",
    "Week" : "Tuần",
    "Month" : "Tháng",
    "Download" : "Tải về",
    "Delete" : "Xóa",
    "Share link" : "Liên kết chia sẽ",
    "Share with users or groups" : "Chia sẽ với người dùng hoặc nhóm",
    "can edit" : "có thể chỉnh sửa",
    "New calendar" : "Lịch mới",
    "Filename" : "Tên tập tin",
    "Cancel" : "Hủy",
    "Show week numbers" : "Hiển thị số tuần",
    "Settings & import" : "Thiết lập & Nhập vào",
    "Email" : "Thư điện tử",
    "Unknown" : "Không xác định",
    "from" : "từ",
    "to" : "đến",
    "never" : "không thay đổi",
    "after" : "sau khi",
    "Repeat" : "Lặp lại",
    "Monday" : "Thứ 2",
    "More" : "hơn",
    "Save" : "Lưu",
    "Update" : "Cập nhật",
    "Personal" : "Cá nhân",
    "Details" : "Chi tiết",
    "Attendees" : "Người tham gia",
    "Reminders" : "Nhắc nhở",
    "Activity" : "Hoạt động",
    "Close" : "Đóng",
    "Anniversary" : "Ngày kỷ niệm",
    "Week {number} of {year}" : "Tuần thứ {number} của năm {year}",
    "Daily" : "Hằng ngày",
    "Weekly" : "Hằng tuần",
    "When shared show full event" : "Khi được chia sẻ thì thể hiện đầy đủ sự kiện",
    "When shared show only busy" : "Khi được chia sẻ thì chỉ thể hiện đang bận",
    "When shared hide this event" : "Khi được chia sẻ thì ẩn sự kiện này đi",
    "Location" : "Vị trí",
    "Description" : "Mô tả",
    "Status" : "Trạng thái",
    "Confirmed" : "Đã xác nhận",
    "Tentative" : "Chưa chắc chắn",
    "Cancelled" : "Đã hủy",
    "Presentation" : "Trình bày",
    "Mail" : "Thư điện tử",
    "Play" : "Play",
    "Global" : "Chung"
},
"nplurals=1; plural=0;");
